==> customer-link-project-api-0.0.99-20230506.063518-3-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app86760/vo/ProductVO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app86760.vo;

import com.alibaba.fastjson.annotation.JSONField;

/**
 * write_your_class_description_here
 *
 * @author xulei
 * @since 1.0.0
 */
public class ProductVO extends BaseVO {

    /**
     * 产品类型
     */
    @JSONField(name = "PRODUCT_TYPE")
    private String productType;

    /**
     * 产品类型
     */
    @JSONField(name = "CLASSIFICATION")
    private String classification;

    /**
     * 产品属性
     */
    @JSONField(name = "PRODUCT_PARA")
    private String productPara;

    /**
     * 产品代码
     */
    @JSONField(name = "PRODUCTCODE")
    private String productCode;

    /**
     * 产品名称
     */
    @JSONField(name = "PRODUCTNAME")
    private String productName;

    /**
     * 青岛银行属性
     */
    @JSONField(name = "PROATTRIBUTE")
    private String proAttribute;

    /**
     * 收益率
     */
    @JSONField(name = "RATE")
    private String rate;

    /**
     * 产品状态
     */
    @JSONField(name = "STATE")
    private String state;

    /**
     * 黄金价格
     */
    @JSONField(name = "GOLDPRICE")
    private String goldPrice;

    /**
     * 风险等级 短债跳转页面用到
     */
    @JSONField(name = "RISKLEVEL")
    private String riskLevel;

    /**
     * 最低投资额度
     */
    @JSONField(name = "MININVEST")
    private String minInvest;

    /**
     * 收益描述
     */
    @JSONField(name = "REMARK1")
    private String remark1;

    /**
     * 营销话术
     */
    @JSONField(name = "REMARK2")
    private String remark2;

    /**
     * 产品链接
     */
    @JSONField(name = "PRODUCTURL")
    private String productUrl;

    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }

    public String getClassification() {
        return classification;
    }

    public void setClassification(String classification) {
        this.classification = classification;
    }

    public String getProductPara() {
        return productPara;
    }

    public void setProductPara(String productPara) {
        this.productPara = productPara;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getProAttribute() {
        return proAttribute;
    }

    public void setProAttribute(String proAttribute) {
        this.proAttribute = proAttribute;
    }

    public String getRate() {
        return rate;
    }

    public void setRate(String rate) {
        this.rate = rate;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getGoldPrice() {
        return goldPrice;
    }

    public void setGoldPrice(String goldPrice) {
        this.goldPrice = goldPrice;
    }

    public String getRiskLevel() {
        return riskLevel;
    }

    public void setRiskLevel(String riskLevel) {
        this.riskLevel = riskLevel;
    }

    public String getMinInvest() {
        return minInvest;
    }

    public void setMinInvest(String minInvest) {
        this.minInvest = minInvest;
    }

    public String getRemark1() {
        return remark1;
    }

    public void setRemark1(String remark1) {
        this.remark1 = remark1;
    }

    public String getRemark2() {
        return remark2;
    }

    public void setRemark2(String remark2) {
        this.remark2 = remark2;
    }

    public String getProductUrl() {
        return productUrl;
    }

    public void setProductUrl(String productUrl) {
        this.productUrl = productUrl;
    }
}

==> customer-link-project-api-1.0.1-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app86760/vo/ProductVO.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app86760.vo;

import com.alibaba.fastjson.annotation.JSONField;

/**
 * write_your_class_description_here
 *
 * @author xulei
 * @since 1.0.0
 */
public class ProductVO {

    /**
     * 产品类型
     */
    @JSONField(name = "PRODUCT_TYPE")
    private String productType;

    /**
     * 产品类型
     */
    @JSONField(name = "CLASSIFICATION")
    private String classification;

    /**
     * 产品属性
     */
    @JSONField(name = "PRODUCT_PARA")
    private String productPara;

    /**
     * 产品代码
     */
    @JSONField(name = "PRODUCTCODE")
    private String productCode;

    /**
     * 产品名称
     */
    @JSONField(name = "PRODUCTNAME")
    private String productName;

    /**
     * 青岛银行属性
     */
    @JSONField(name = "PROATTRIBUTE")
    private String proAttribute;

    /**
     * 收益率
     */
    @JSONField(name = "RATE")
    private String rate;

    /**
     * 产品状态
     */
    @JSONField(name = "STATE")
    private String state;

    /**
     * 黄金价格
     */
    @JSONField(name = "GOLDPRICE")
    private String goldPrice;

    /**
     * 风险等级 短债跳转页面用到
     */
    @JSONField(name = "RISKLEVEL")
    private String riskLevel;

    /**
     * 最低投资额度
     */
    @JSONField(name = "MININVEST")
    private String minInvest;

    /**
     * 收益描述
     */
    @JSONField(name = "REMARK1")
    private String remark1;

    /**
     * 营销话术
     */
    @JSONField(name = "REMARK2")
    private String remark2;

    /**
     * 产品链接
     */
    @JSONField(name = "PRODUCTURL")
    private String productUrl;

    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }

    public String getClassification() {
        return classification;
    }

    public void setClassification(String classification) {
        this.classification = classification;
    }

    public String getProductPara() {
        return productPara;
    }

    public void setProductPara(String productPara) {
        this.productPara = productPara;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getProAttribute() {
        return proAttribute;
    }

    public void setProAttribute(String proAttribute) {
        this.proAttribute = proAttribute;
    }

    public String getRate() {
        return rate;
    }

    public void setRate(String rate) {
        this.rate = rate;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getGoldPrice() {
        return goldPrice;
    }

    public void setGoldPrice(String goldPrice) {
        this.goldPrice = goldPrice;
    }

    public String getRiskLevel() {
        return riskLevel;
    }

    public void setRiskLevel(String riskLevel) {
        this.riskLevel = riskLevel;
    }

    public String getMinInvest() {
        return minInvest;
    }

    public void setMinInvest(String minInvest) {
        this.minInvest = minInvest;
    }

    public String getRemark1() {
        return remark1;
    }

    public void setRemark1(String remark1) {
        this.remark1 = remark1;
    }

    public String getRemark2() {
        return remark2;
    }

    public void setRemark2(String remark2) {
        this.remark2 = remark2;
    }

    public String getProductUrl() {
        return productUrl;
    }

    public void setProductUrl(String productUrl) {
        this.productUrl = productUrl;
    }
}
